/* $Id: driver_test.c,v 1.2 2004/04/09 11:28:17 dijkstra Exp $ */

/*
 * Copyright (c) 2004 Willem Dijkstra
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 *    - Redistributions of source code must retain the above copyright
 *      notice, this list of conditions and the following disclaimer.
 *    - Redistributions in binary form must reproduce the above
 *      copyright notice, this list of conditions and the following
 *      disclaimer in the documentation and/or other materials provided
 *      with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 * COPYRIGHT HOLDERS OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
 * ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 */

#ifdef TEST
#include <stdio.h>
#include <string.h>
#include <errno.h>

#include "lcd.h"
#include "error.h"
#include "driver_test.h"

char *driver_name = "Test";
int   driver_capabilities = 0;
char frame[LCD_X+3];

void
driver_init(char *serial, int capabilities)
{
    int i;

    debug("initialize %s driver @ %s", driver_name, serial);

    frame[0]='+';
    for (i=0; i<LCD_X; i++) {
	frame[i+1]='-';
    }
    frame[LCD_X+1]='+';
    frame[LCD_X+2]=0;
}

void
driver_reset()
{
    info("driver:reset\n");
}

void
driver_flush()
{
    char format[LCD_X + 3];
    int i;

    snprintf(format, sizeof(format), "|%%.%ds|", LCD_X);
    info(frame);
    for (i=0; i<LCD_Y; i++) {
	info(format, lcd_framebuffer + (i * LCD_X));
    }
    info(frame);
}

void
driver_put_block(int x, int y)
{
    lcd_set(x, y, 'B');
}

void
driver_put_vchar(int x, int y, int percentage)
{
    int unit;
    int i;

    if (percentage > 100) {
	percentage = 100;
    }

    if (percentage < 0) {
	percentage = 0;
    }

    if (percentage == 100) {
	lcd_set(x, y, '8');
	return;
    }

    if (percentage == 0) {
	lcd_set(x, y, '0');
	return;
    }

    unit = 1000/8;

    percentage += 5;
    percentage *= 10;

    i = percentage / unit;

    lcd_set(x, y, '0' + i);
}
#endif /* DRIVER_TEST */
